﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using NFC.Resources;
using Windows.Networking.Proximity;

namespace NFC
{
    public partial class MainPage : PhoneApplicationPage
    {
        ProximityDevice device;

        long typeId = -1;
        long msgId = -1;
        public MainPage()
        {
            InitializeComponent();

            device = ProximityDevice.GetDefault();
            if (device == null)
            {
                IsEnabled = false;
                textblock1.Text = "您的手机不支持NFC功能";
            }
            else
            {
                //设备进入NFC识别范围时触发
                device.DeviceArrived += device_DeviceArrived;
                //设备离开NFC识别范围时触发
                device.DeviceDeparted += device_DeviceDeparted;
            }
        }

        //设备进入NFC识别范围时触发
        void device_DeviceArrived(ProximityDevice sender)
        {
            //创建消息订阅，创建好后就可以直接发消息了
            typeId = sender.SubscribeForMessage("Windows.MyMsgType", MsgReceivedHandler);
            Dispatcher.BeginInvoke(() => textblock1.Text = "连接状态：已连接");
        }

        //设备离开NFC识别范围时触发
        void device_DeviceDeparted(ProximityDevice sender)
        {
            if (typeId != -1)
            {
                //取消消息订阅
                sender.StopSubscribingForMessage(typeId);
                typeId = -1;
            }

            Dispatcher.BeginInvoke(() => textblock1.Text = "连接状态：连接中断");
        }

        /// <summary>
        /// 接收到消息后的处理逻辑
        /// </summary>
        void MsgReceivedHandler(ProximityDevice sender, ProximityMessage message)
        {
            Dispatcher.BeginInvoke(() =>
            {
                listbox1.Items.Add(("对方：" + message.DataAsString));
            }); 
        }

        /// <summary>
        /// 发送消息按钮按下时
        /// </summary>
        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            if (textbox1.Text != string.Empty)
            {
                listbox1.Items.Add("我：" + textbox1.Text);

                if (msgId != -1)
                    device.StopPublishingMessage(msgId);

                msgId = device.PublishMessage("Windows.MyMsgType", textbox1.Text);
            }
        }
    }
}